package com.example.elbuenopeso.ui.market

import AdAdapter
import android.database.Cursor
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.GridView
import android.widget.CursorAdapter
import android.widget.ListView
import android.widget.ToggleButton
import androidx.fragment.app.Fragment
import androidx.lifecycle.ViewModelProvider
import com.example.elbuenopeso.databinding.FragmentMarketBinding
import com.example.elbuenopeso.models.AdModel
import com.example.elbuenopeso.R
import com.example.elbuenopeso.adapters.DbAdapter
import com.example.elbuenopeso.database.DBManager

class MarketFragment : Fragment() {

    private var _binding: FragmentMarketBinding? = null

    // This property is only valid between onCreateView and
    // onDestroyView.
    private val binding get() = _binding!!

    private lateinit var listView: ListView
    private lateinit var gridView: GridView
    private lateinit var toggleButton: ToggleButton
    private lateinit var adAdapter: AdAdapter

    private var isGridViewEnabled = false

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        val marketViewModel =
            ViewModelProvider(this)[MarketViewModel::class.java]

        _binding = FragmentMarketBinding.inflate(inflater, container, false)
        val root: View = binding.root
        listView = binding.listView
        gridView = binding.gridView
        toggleButton = binding.toggleButton

        val listView: ListView = binding.listView
        // seed market items
        var annonces: List<AdModel> = listOf<AdModel>(
            AdModel("Poutre", "1 rue Jean-Pierre", R.drawable.pichu, 25.0),
            AdModel("Briques", "2 rue Jean-Michel", R.drawable.pichu, 16.0),
            AdModel("Mur en bois", "4 rue Alain-Juju", R.drawable.pichu, 7.2),
            AdModel("Maison de pierre", "7 rue Joris Belhomme", R.drawable.pichu, 3.99),
            AdModel("Téléphone de Timothé", "8 rue de Timothé", R.drawable.pichu, 0.85),
            AdModel("Oridnateur", "10 rue Jean-Charles", R.drawable.pichu, 104.98),
            AdModel("Charnières", "22 rue Jeanne-Marie", R.drawable.pichu, 2648.97),
            AdModel("Porte en marbre", "1 rue Jean-Pierre", R.drawable.pichu, 480.0),
            AdModel("Cheminée", "33 rue du Gouvernement", R.drawable.pichu, 800.0),
        )

        toggleButton.setOnCheckedChangeListener { _, isChecked ->
            isGridViewEnabled = isChecked
            updateView()
        }

        val dbManager: DBManager? = DBManager.getDBManager(requireContext())
        dbManager!!.init()
        val cursor = dbManager.fetch()
        Log.i(null, cursor?.getColumnName(0).toString())
        val adapter = DbAdapter(requireContext(), cursor!!, R.layout.item_listview_ad)
        adapter.notifyDataSetChanged()
        listView.adapter = adapter
        return root
    }

    private fun updateView() {
        if (isGridViewEnabled) {
            listView.visibility = View.GONE
            gridView.visibility = View.VISIBLE
            gridView.adapter = adAdapter
        } else {
            gridView.visibility = View.GONE
            listView.visibility = View.VISIBLE
            listView.adapter = adAdapter
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}